@@ -5,7 +5,8 @@ from typing import List, Optional
 from rlbot.agents.base_agent import BaseAgent
 from rlbot.matchcomms.client import MatchcommsClient
 
-from tmcp import TMCP_VERSION, TMCPMessage
+from tmcp import TMCP_VERSION
+from .message import TMCPMessage
 
 
 MAX_PACKETS_PER_TICK: int = 50
@@ -26,7 +27,7 @@ class TMCPHandler:
 
     ```
     def get_output(self, packet: GameTickPacket) -> SimpleControllerState:
-        # Receive and parse all new matchcomms messages into TMCPMessage objects
+        # Receive and parse all new matchcomms messages into TMCPMessage objects.
         new_messages: List[TMCPMessage] = self.tmcp_handler.recv()
         # Handle TMCPMessages.
         for message in new_messages:
